This is a platform-agnostic Rust driver for the NXP PCAL6416A IO Expander
based on the embedded-hal traits.
For further details of the device architecture and operation, please refer
to the official Datasheet.
PCAL6416A Rust Device Driver
A #[no_std] platform-agnostic driver for the PCAL6416A IO Expander
MSRV
Currently, rust 1.81 and up is supported.
License
Licensed under the terms of the MIT license.
Contribution
Unless you explicitly state otherwise, any contribution submitted for inclusion in the work by you shall be licensed under the terms of the MIT license.
License: MIT
Modules
- field_
sets - Module containing the generated fieldsets of the registers and commands
Structs
- Device
- Root block of the Device driver
- Pcal6416a
Device